==> igniteui-webcomponents-core-4.0.2.tgz: package/esm2015/lib/OnPopupEventArgsDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { OnPopupEventArgsDescription } from "./OnPopupEventArgsDescription";
/**
 * @hidden
 */
export let OnPopupEventArgsDescriptionMetadata = /*@__PURE__*/ (() => {
    class OnPopupEventArgsDescriptionMetadata extends Base {
        static b(a) {
            if (OnPopupEventArgsDescriptionMetadata.a == null) {
                OnPopupEventArgsDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
                OnPopupEventArgsDescriptionMetadata.c(OnPopupEventArgsDescriptionMetadata.a);
            }
            if (a.j(OnPopupEventArgsDescriptionMetadata.a)) {
                return;
            }
            a.y(OnPopupEventArgsDescriptionMetadata.a);
        }
        static c(a) {
        }
        static d(a) {
            OnPopupEventArgsDescriptionMetadata.b(a);
            a.aa("OnPopupEventArgs", () => new OnPopupEventArgsDescription());
            a.z("OnPopupEventArgs", OnPopupEventArgsDescriptionMetadata.a);
        }
    }
    OnPopupEventArgsDescriptionMetadata.$t = /*@__PURE__*/ markType(OnPopupEventArgsDescriptionMetadata, 'OnPopupEventArgsDescriptionMetadata');
    OnPopupEventArgsDescriptionMetadata.a = null;
    return OnPopupEventArgsDescriptionMetadata;
})();

==> igniteui-webcomponents-core-4.2.5.tgz: package/esm2015/lib/OnPopupEventArgsDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { OnPopupEventArgsDescription } from "./OnPopupEventArgsDescription";
/**
 * @hidden
 */
export let OnPopupEventArgsDescriptionMetadata = /*@__PURE__*/ (() => {
    class OnPopupEventArgsDescriptionMetadata extends Base {
        static b(a) {
            if (OnPopupEventArgsDescriptionMetadata.a == null) {
                OnPopupEventArgsDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
                OnPopupEventArgsDescriptionMetadata.c(OnPopupEventArgsDescriptionMetadata.a);
            }
            if (a.k(OnPopupEventArgsDescriptionMetadata.a)) {
                return;
            }
            a.aa(OnPopupEventArgsDescriptionMetadata.a);
        }
        static c(a) {
        }
        static d(a) {
            OnPopupEventArgsDescriptionMetadata.b(a);
            a.ac("OnPopupEventArgs", () => new OnPopupEventArgsDescription());
            a.ab("OnPopupEventArgs", OnPopupEventArgsDescriptionMetadata.a);
        }
    }
    OnPopupEventArgsDescriptionMetadata.$t = /*@__PURE__*/ markType(OnPopupEventArgsDescriptionMetadata, 'OnPopupEventArgsDescriptionMetadata');
    OnPopupEventArgsDescriptionMetadata.a = null;
    return OnPopupEventArgsDescriptionMetadata;
})();
